@@ -1,4 +1,4 @@
-package Trog::TOTP 1.002;
+package Trog::TOTP 1.003;
 
 use strict;
 use warnings;
@@ -336,7 +336,7 @@ Trog::TOTP - Fork of Authen::TOTP
 
 =head1 VERSION
 
-version 1.002
+version 1.003
 
 =head1 DESCRIPTION
 
@@ -350,7 +350,7 @@ Trog::TOTP - Interface to RFC6238 two factor authentication (2FA)
 
 =head1 USAGE
 
- my $gen = Authen::TOTP->new(
+ my $gen = Trog::TOTP->new(
      # not needed when setting up TOTP for the first time;
      # we generate a secret automatically which you should grab and store.
 	 secret		=>	"some_random_stuff",
@@ -363,7 +363,7 @@ Trog::TOTP - Interface to RFC6238 two factor authentication (2FA)
  );
 
  # Be sure to store this as binary data
- my $secret = $get->secret();
+ my $secret = $gen->secret();
 
  # This is what you will want to show users for input into their TOTP apps when their camera is failing
  my $b32secret = $gen->base32secret();
@@ -400,7 +400,7 @@ Trog::TOTP - Interface to RFC6238 two factor authentication (2FA)
 
 =head2 new
 
- my $gen = Authen::TOTP->new(
+ my $gen = Trog::TOTP->new(
 	 digits 	=>	[6|8],
 	 period		=>	[30|60],
 	 algorithm	=>	"SHA1", #SHA256 and SHA512 are equally valid
